import os 
import sys 
import time 
import boto3

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def taskchecker():
    client = boto3.client('route53')
    fulllist = client.list_hosted_zones()
    HZONELIST = (fulllist["HostedZones"])

    # Creates a variable for Hosted Zone ID
    for i in HZONELIST:
        RAWHZONEID = i["Id"]
        HZONEID = RAWHZONEID.split("/")[2]

    for i in HZONELIST:
        HNAME = i["Name"]



    response = client.list_resource_record_sets(
        HostedZoneId=HZONEID
    )


    RR = response["ResourceRecordSets"]
    for i in RR:
        NAMETUPLE    = i["Name"], 
        TYPELIST    = i["Type"]
        NAMELIST    = ''.join(NAMETUPLE)
    if "1sdf" in NAMELIST:
        print(HNAME)
        print(bcolors.OKGREEN + "CNAME is created"+ bcolors.ENDC)
    else:
        print(bcolors.OKGREEN + "CNAME is created"+ bcolors.ENDC)

taskchecker()
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 



import os
import re 
import sys 
import time 
import boto3
import json 
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def accountverifier():
    result = boto3.client('sts').get_caller_identity().get('Account')
    if result == "713287746880":
        print(bcolors.FAIL + "You are running in a wrong account, please configure your account by running 'aws configure'"  + bcolors.ENDC)
        sys.exit(1)



import boto3
def zone_id_finder():
    client = boto3.client('route53')
    fulllist = client.list_hosted_zones()
    HZONELIST = (fulllist["HostedZones"])

    # Creates a variable for Hosted Zone ID
    for i in HZONELIST:
        RAWHZONEID = i["Id"]
        HZONEID = RAWHZONEID.split("/")[2]
        return HZONEID



import os
import re 
import sys 
import time 
import boto3
import json 
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def taskchecker():
    try:
        REGION="us-east-2"
        FUNCTIONNAME="HelloWorld"
        FUNCTIONPYTHON="python3.7"
        TOTALMEMORY=256
        FUNCTIONTIMEOUT=120
        client = boto3.client('lambda', region_name=REGION)
        response = client.list_functions()        

        RESULT = response["Functions"][0]
        FOUNDFUNCTIONNAME = RESULT["FunctionName"]
        FOUNDFUNCTIONPYTHON = RESULT["Runtime"]
        FOUNDFUNCTIONMEMORY = RESULT["MemorySize"]
        FOUNDFUNCTIONTIMEOUT = RESULT["Timeout"]

        if FOUNDFUNCTIONNAME in FUNCTIONNAME:
            print(bcolors.OKGREEN + "Function is created in %s " % REGION + bcolors.ENDC)
            time.sleep(0.5)
        else:
            print(bcolors.FAIL + "Function is not created %s " % REGION + bcolors.ENDC)
            sys.exit(1)
            time.sleep(0.5)


        if FOUNDFUNCTIONPYTHON == FUNCTIONPYTHON:
            print(bcolors.OKGREEN + "Function python is correct" + bcolors.ENDC)
            time.sleep(0.5)
        else:
            print(bcolors.FAIL + "Function python is not correct, it should be %s" % FUNCTIONPYTHON + bcolors.ENDC)
            sys.exit(1)
            time.sleep(0.5)

        if FOUNDFUNCTIONMEMORY == TOTALMEMORY:
            print(bcolors.OKGREEN + "Function memory is correct" + bcolors.ENDC)
            time.sleep(0.5)
        else:
            print(bcolors.FAIL + "Function memory is not correct, it should be %s, please update by Function >> Configuration >> >> General Configuration" % TOTALMEMORY + bcolors.ENDC)
            sys.exit(1)
            time.sleep(0.5)
        
        if FOUNDFUNCTIONTIMEOUT == FUNCTIONTIMEOUT:
            print(bcolors.OKGREEN + "Function timeout is correct" + bcolors.ENDC)
            time.sleep(0.5)
        else:
            print(bcolors.FAIL + "Function timeout is not correct, it should be %s, please update by Function >> Configuration >> >> General Configuration" % FUNCTIONTIMEOUT + bcolors.ENDC)
            time.sleep(0.5)
            sys.exit(1)


    except:
        print(bcolors.FAIL + "Something went wrong or you did the task in wrong region should be in %s, please redo the task" % REGION +  bcolors.ENDC)
        time.sleep(0.5)
        sys.exit(1)

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
